#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Path
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_AutoCloseDrawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=100.0,height=100.0,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		v0=self._nn(Group())
		v0.transform = (1,0,0,-1,0,100)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,-1,0,100)
		v1.add(Path(points=[10,10,10,90,20,90,20,10,30,10,30,90,40,90,40,10,50,10,50,90,60,90,60,10,70,10,70,90,80,90,80,10],operators=[0,1,1,1,3,0,1,1,1,0,1,1,1,3,0,1,1,1],isClipPath=0,autoclose=None,fillMode=1,fillColor=Color(0,0,1,1),fillOpacity=1,strokeColor=Color(1,0,0,1),strokeWidth=2,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_AutoCloseDrawing().save(formats=['pdf'],outDir='.',fnRoot=None)
