#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=756.284,height=240.20000000000002,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(8,208.4,569.068,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,215.8,'Times-Roman: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='Times-Roman',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,179,631.832,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,186.4,'Vera: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='Vera',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,149.6,598.216,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,157,'Times-BoldItalic: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='Times-BoldItalic',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,120.2,740.284,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,127.6,'Courier: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='Courier',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,90.8,592.504,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,98.2,'Helvetica: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='Helvetica',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,61.4,716.459,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,68.8,'VeraBd: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='VeraBd',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,32,640.0762,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,39.4,'VeraIt: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='VeraIt',fontSize=12,fillColor=Color(0,0,0,1)))
		self.add(Rect(8,2.6,712.334,24.4,rx=0,ry=0,fillColor=Color(.827451,.827451,.827451,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(10,10,'VeraBI: I should be totally horizontal and enclosed in a box and end in alphabetagamma ¢©®£ʥЖփאقকαβγ',textAnchor='start',fontName='VeraBI',fontSize=12,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
