#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, String, Line
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		v0=self._nn(Group())
		v0.transform = (0,-1,1,0,100,175)
		v0.add(Rect(2.5,50,10,-37.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(17.5,50,10,7.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(32.5,50,10,12.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(47.5,50,10,25,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(62.5,50,10,20,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(77.5,50,10,17.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(92.5,50,10,10,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(107.5,50,10,2.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(122.5,50,10,25,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(137.5,50,10,7.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,7.5,2.5)
		v1.add(String(-6.837,-2.4,'-1.50',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,22.5,67.5)
		v1.add(String(5.838,-2.4,'0.30',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,37.5,72.5)
		v1.add(String(5.838,-2.4,'0.50',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,52.5,85)
		v1.add(String(5.838,-2.4,'1.00',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,67.5,80)
		v1.add(String(5.838,-2.4,'0.80',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,82.5,77.5)
		v1.add(String(5.838,-2.4,'0.70',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,97.5,70)
		v1.add(String(5.838,-2.4,'0.40',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,112.5,62.5)
		v1.add(String(5.838,-2.4,'0.10',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,127.5,85)
		v1.add(String(5.838,-2.4,'1.00',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,142.5,67.5)
		v1.add(String(5.838,-2.4,'0.30',textAnchor='middle',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v0.add(Line(0,50,150,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,7.5,-75)
		v1.add(String(0,-2.4,'UK Equities',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,22.5,-75)
		v1.add(String(0,-2.4,'US Equities',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,37.5,-75)
		v1.add(String(0,-2.4,'European Equities',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,52.5,-75)
		v1.add(String(0,-2.4,'Japanese Equities',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,67.5,-75)
		v1.add(String(0,-2.4,'Pacific (ex Japan) Equities',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,82.5,-75)
		v1.add(String(0,-2.4,'Emerging Markets Equities',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,97.5,-75)
		v1.add(String(0,-2.4,'UK Bonds',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,112.5,-75)
		v1.add(String(0,-2.4,'Overseas Bonds',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,127.5,-75)
		v1.add(String(0,-2.4,'UK Index-Linked',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))
		v1=v0._nn(Group())
		v1.transform = (0,1,-1,0,142.5,-75)
		v1.add(String(0,-2.4,'Cash',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
