#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Line, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(50,50,300,125,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(97.85714,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.090909,.090909,1),fillOpacity=None,strokeColor=Color(1,.090909,.090909,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(100.7143,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.181818,.181818,1),fillOpacity=None,strokeColor=Color(1,.181818,.181818,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(103.5714,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.272727,.272727,1),fillOpacity=None,strokeColor=Color(1,.272727,.272727,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(106.4286,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.363636,.363636,1),fillOpacity=None,strokeColor=Color(1,.363636,.363636,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(109.2857,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.454545,.454545,1),fillOpacity=None,strokeColor=Color(1,.454545,.454545,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(112.1429,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.545455,.545455,1),fillOpacity=None,strokeColor=Color(1,.545455,.545455,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(115,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.636364,.636364,1),fillOpacity=None,strokeColor=Color(1,.636364,.636364,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(117.8571,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.727273,.727273,1),fillOpacity=None,strokeColor=Color(1,.727273,.727273,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(120.7143,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.818182,.818182,1),fillOpacity=None,strokeColor=Color(1,.818182,.818182,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(123.5714,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.909091,.909091,1),fillOpacity=None,strokeColor=Color(1,.909091,.909091,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(126.4286,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(129.2857,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.888889,.888889,1),fillOpacity=None,strokeColor=Color(1,.888889,.888889,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(132.1429,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.777778,.777778,1),fillOpacity=None,strokeColor=Color(1,.777778,.777778,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(135,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.666667,.666667,1),fillOpacity=None,strokeColor=Color(1,.666667,.666667,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(137.8571,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.555556,.555556,1),fillOpacity=None,strokeColor=Color(1,.555556,.555556,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(140.7143,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.444444,.444444,1),fillOpacity=None,strokeColor=Color(1,.444444,.444444,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(143.5714,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.333333,.333333,1),fillOpacity=None,strokeColor=Color(1,.333333,.333333,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(146.4286,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.222222,.222222,1),fillOpacity=None,strokeColor=Color(1,.222222,.222222,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(149.2857,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,.111111,.111111,1),fillOpacity=None,strokeColor=Color(1,.111111,.111111,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(152.1429,50,2.857143,6.944444,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,50,60,6.944444,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(247.8571,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.090909,.090909,1),fillOpacity=None,strokeColor=Color(1,.090909,.090909,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(250.7143,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.181818,.181818,1),fillOpacity=None,strokeColor=Color(1,.181818,.181818,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(253.5714,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.272727,.272727,1),fillOpacity=None,strokeColor=Color(1,.272727,.272727,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(256.4286,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.363636,.363636,1),fillOpacity=None,strokeColor=Color(1,.363636,.363636,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(259.2857,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.454545,.454545,1),fillOpacity=None,strokeColor=Color(1,.454545,.454545,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(262.1429,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.545455,.545455,1),fillOpacity=None,strokeColor=Color(1,.545455,.545455,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(265,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.636364,.636364,1),fillOpacity=None,strokeColor=Color(1,.636364,.636364,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(267.8571,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.727273,.727273,1),fillOpacity=None,strokeColor=Color(1,.727273,.727273,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(270.7143,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.818182,.818182,1),fillOpacity=None,strokeColor=Color(1,.818182,.818182,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(273.5714,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.909091,.909091,1),fillOpacity=None,strokeColor=Color(1,.909091,.909091,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(276.4286,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(279.2857,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.888889,.888889,1),fillOpacity=None,strokeColor=Color(1,.888889,.888889,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(282.1429,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.777778,.777778,1),fillOpacity=None,strokeColor=Color(1,.777778,.777778,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(285,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.666667,.666667,1),fillOpacity=None,strokeColor=Color(1,.666667,.666667,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(287.8571,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.555556,.555556,1),fillOpacity=None,strokeColor=Color(1,.555556,.555556,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(290.7143,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.444444,.444444,1),fillOpacity=None,strokeColor=Color(1,.444444,.444444,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(293.5714,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.333333,.333333,1),fillOpacity=None,strokeColor=Color(1,.333333,.333333,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(296.4286,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.222222,.222222,1),fillOpacity=None,strokeColor=Color(1,.222222,.222222,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(299.2857,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,.111111,.111111,1),fillOpacity=None,strokeColor=Color(1,.111111,.111111,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(302.1429,50,2.857143,41.66667,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,50,60,41.66667,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,0,1,1),fillOpacity=None,strokeColor=Color(1,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(97.85714,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.090909,1,1),fillOpacity=None,strokeColor=Color(1,.090909,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(100.7143,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.181818,1,1),fillOpacity=None,strokeColor=Color(1,.181818,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(103.5714,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.272727,1,1),fillOpacity=None,strokeColor=Color(1,.272727,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(106.4286,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.363636,1,1),fillOpacity=None,strokeColor=Color(1,.363636,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(109.2857,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.454545,1,1),fillOpacity=None,strokeColor=Color(1,.454545,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(112.1429,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.545455,1,1),fillOpacity=None,strokeColor=Color(1,.545455,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(115,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.636364,1,1),fillOpacity=None,strokeColor=Color(1,.636364,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(117.8571,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.727273,1,1),fillOpacity=None,strokeColor=Color(1,.727273,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(120.7143,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.818182,1,1),fillOpacity=None,strokeColor=Color(1,.818182,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(123.5714,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.909091,1,1),fillOpacity=None,strokeColor=Color(1,.909091,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(126.4286,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(129.2857,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.888889,1,1),fillOpacity=None,strokeColor=Color(1,.888889,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(132.1429,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.777778,1,1),fillOpacity=None,strokeColor=Color(1,.777778,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(135,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.666667,1,1),fillOpacity=None,strokeColor=Color(1,.666667,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(137.8571,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.555556,1,1),fillOpacity=None,strokeColor=Color(1,.555556,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(140.7143,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.444444,1,1),fillOpacity=None,strokeColor=Color(1,.444444,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(143.5714,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.333333,1,1),fillOpacity=None,strokeColor=Color(1,.333333,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(146.4286,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.222222,1,1),fillOpacity=None,strokeColor=Color(1,.222222,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(149.2857,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,.111111,1,1),fillOpacity=None,strokeColor=Color(1,.111111,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(152.1429,56.94444,2.857143,13.88889,rx=0,ry=0,fillColor=Color(1,0,1,1),fillOpacity=None,strokeColor=Color(1,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,56.94444,60,13.88889,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,0,1,1),fillOpacity=None,strokeColor=Color(1,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(247.8571,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.090909,1,1),fillOpacity=None,strokeColor=Color(1,.090909,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(250.7143,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.181818,1,1),fillOpacity=None,strokeColor=Color(1,.181818,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(253.5714,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.272727,1,1),fillOpacity=None,strokeColor=Color(1,.272727,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(256.4286,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.363636,1,1),fillOpacity=None,strokeColor=Color(1,.363636,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(259.2857,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.454545,1,1),fillOpacity=None,strokeColor=Color(1,.454545,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(262.1429,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.545455,1,1),fillOpacity=None,strokeColor=Color(1,.545455,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(265,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.636364,1,1),fillOpacity=None,strokeColor=Color(1,.636364,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(267.8571,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.727273,1,1),fillOpacity=None,strokeColor=Color(1,.727273,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(270.7143,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.818182,1,1),fillOpacity=None,strokeColor=Color(1,.818182,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(273.5714,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.909091,1,1),fillOpacity=None,strokeColor=Color(1,.909091,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(276.4286,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(279.2857,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.888889,1,1),fillOpacity=None,strokeColor=Color(1,.888889,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(282.1429,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.777778,1,1),fillOpacity=None,strokeColor=Color(1,.777778,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(285,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.666667,1,1),fillOpacity=None,strokeColor=Color(1,.666667,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(287.8571,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.555556,1,1),fillOpacity=None,strokeColor=Color(1,.555556,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(290.7143,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.444444,1,1),fillOpacity=None,strokeColor=Color(1,.444444,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(293.5714,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.333333,1,1),fillOpacity=None,strokeColor=Color(1,.333333,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(296.4286,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.222222,1,1),fillOpacity=None,strokeColor=Color(1,.222222,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(299.2857,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,.111111,1,1),fillOpacity=None,strokeColor=Color(1,.111111,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(302.1429,91.66667,2.857143,34.72222,rx=0,ry=0,fillColor=Color(1,0,1,1),fillOpacity=None,strokeColor=Color(1,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,91.66667,60,34.72222,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(97.85714,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.090909,.547237,.090909,1),fillOpacity=None,strokeColor=Color(.090909,.547237,.090909,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(100.7143,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.181818,.592513,.181818,1),fillOpacity=None,strokeColor=Color(.181818,.592513,.181818,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(103.5714,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.272727,.63779,.272727,1),fillOpacity=None,strokeColor=Color(.272727,.63779,.272727,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(106.4286,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.363636,.683066,.363636,1),fillOpacity=None,strokeColor=Color(.363636,.683066,.363636,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(109.2857,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.454545,.728342,.454545,1),fillOpacity=None,strokeColor=Color(.454545,.728342,.454545,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(112.1429,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.545455,.773619,.545455,1),fillOpacity=None,strokeColor=Color(.545455,.773619,.545455,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(115,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.636364,.818895,.636364,1),fillOpacity=None,strokeColor=Color(.636364,.818895,.636364,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(117.8571,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.727273,.864171,.727273,1),fillOpacity=None,strokeColor=Color(.727273,.864171,.727273,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(120.7143,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.818182,.909447,.818182,1),fillOpacity=None,strokeColor=Color(.818182,.909447,.818182,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(123.5714,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.909091,.954724,.909091,1),fillOpacity=None,strokeColor=Color(.909091,.954724,.909091,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(126.4286,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(129.2857,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.888889,.944662,.888889,1),fillOpacity=None,strokeColor=Color(.888889,.944662,.888889,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(132.1429,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.777778,.889325,.777778,1),fillOpacity=None,strokeColor=Color(.777778,.889325,.777778,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(135,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.666667,.833987,.666667,1),fillOpacity=None,strokeColor=Color(.666667,.833987,.666667,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(137.8571,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.555556,.778649,.555556,1),fillOpacity=None,strokeColor=Color(.555556,.778649,.555556,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(140.7143,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.444444,.723312,.444444,1),fillOpacity=None,strokeColor=Color(.444444,.723312,.444444,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(143.5714,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.333333,.667974,.333333,1),fillOpacity=None,strokeColor=Color(.333333,.667974,.333333,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(146.4286,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.222222,.612636,.222222,1),fillOpacity=None,strokeColor=Color(.222222,.612636,.222222,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(149.2857,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.111111,.557298,.111111,1),fillOpacity=None,strokeColor=Color(.111111,.557298,.111111,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(152.1429,70.83333,2.857143,20.83333,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,70.83333,60,20.83333,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(247.8571,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.090909,.547237,.090909,1),fillOpacity=None,strokeColor=Color(.090909,.547237,.090909,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(250.7143,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.181818,.592513,.181818,1),fillOpacity=None,strokeColor=Color(.181818,.592513,.181818,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(253.5714,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.272727,.63779,.272727,1),fillOpacity=None,strokeColor=Color(.272727,.63779,.272727,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(256.4286,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.363636,.683066,.363636,1),fillOpacity=None,strokeColor=Color(.363636,.683066,.363636,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(259.2857,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.454545,.728342,.454545,1),fillOpacity=None,strokeColor=Color(.454545,.728342,.454545,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(262.1429,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.545455,.773619,.545455,1),fillOpacity=None,strokeColor=Color(.545455,.773619,.545455,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(265,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.636364,.818895,.636364,1),fillOpacity=None,strokeColor=Color(.636364,.818895,.636364,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(267.8571,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.727273,.864171,.727273,1),fillOpacity=None,strokeColor=Color(.727273,.864171,.727273,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(270.7143,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.818182,.909447,.818182,1),fillOpacity=None,strokeColor=Color(.818182,.909447,.818182,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(273.5714,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.909091,.954724,.909091,1),fillOpacity=None,strokeColor=Color(.909091,.954724,.909091,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(276.4286,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(279.2857,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.888889,.944662,.888889,1),fillOpacity=None,strokeColor=Color(.888889,.944662,.888889,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(282.1429,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.777778,.889325,.777778,1),fillOpacity=None,strokeColor=Color(.777778,.889325,.777778,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(285,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.666667,.833987,.666667,1),fillOpacity=None,strokeColor=Color(.666667,.833987,.666667,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(287.8571,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.555556,.778649,.555556,1),fillOpacity=None,strokeColor=Color(.555556,.778649,.555556,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(290.7143,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.444444,.723312,.444444,1),fillOpacity=None,strokeColor=Color(.444444,.723312,.444444,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(293.5714,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.333333,.667974,.333333,1),fillOpacity=None,strokeColor=Color(.333333,.667974,.333333,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(296.4286,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.222222,.612636,.222222,1),fillOpacity=None,strokeColor=Color(.222222,.612636,.222222,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(299.2857,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.111111,.557298,.111111,1),fillOpacity=None,strokeColor=Color(.111111,.557298,.111111,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(302.1429,126.3889,2.857143,27.77778,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,126.3889,60,27.77778,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(97.85714,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.090909,.090909,1,1),fillOpacity=None,strokeColor=Color(.090909,.090909,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(100.7143,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.181818,.181818,1,1),fillOpacity=None,strokeColor=Color(.181818,.181818,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(103.5714,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.272727,.272727,1,1),fillOpacity=None,strokeColor=Color(.272727,.272727,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(106.4286,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.363636,.363636,1,1),fillOpacity=None,strokeColor=Color(.363636,.363636,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(109.2857,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.454545,.454545,1,1),fillOpacity=None,strokeColor=Color(.454545,.454545,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(112.1429,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.545455,.545455,1,1),fillOpacity=None,strokeColor=Color(.545455,.545455,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(115,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.636364,.636364,1,1),fillOpacity=None,strokeColor=Color(.636364,.636364,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(117.8571,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.727273,.727273,1,1),fillOpacity=None,strokeColor=Color(.727273,.727273,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(120.7143,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.818182,.818182,1,1),fillOpacity=None,strokeColor=Color(.818182,.818182,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(123.5714,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.909091,.909091,1,1),fillOpacity=None,strokeColor=Color(.909091,.909091,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(126.4286,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(129.2857,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.888889,.888889,1,1),fillOpacity=None,strokeColor=Color(.888889,.888889,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(132.1429,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.777778,.777778,1,1),fillOpacity=None,strokeColor=Color(.777778,.777778,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(135,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.666667,.666667,1,1),fillOpacity=None,strokeColor=Color(.666667,.666667,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(137.8571,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.555556,.555556,1,1),fillOpacity=None,strokeColor=Color(.555556,.555556,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(140.7143,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.444444,.444444,1,1),fillOpacity=None,strokeColor=Color(.444444,.444444,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(143.5714,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.333333,.333333,1,1),fillOpacity=None,strokeColor=Color(.333333,.333333,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(146.4286,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.222222,.222222,1,1),fillOpacity=None,strokeColor=Color(.222222,.222222,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(149.2857,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(.111111,.111111,1,1),fillOpacity=None,strokeColor=Color(.111111,.111111,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(152.1429,91.66667,2.857143,27.77778,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,91.66667,60,27.77778,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(247.8571,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.090909,.090909,1,1),fillOpacity=None,strokeColor=Color(.090909,.090909,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(250.7143,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.181818,.181818,1,1),fillOpacity=None,strokeColor=Color(.181818,.181818,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(253.5714,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.272727,.272727,1,1),fillOpacity=None,strokeColor=Color(.272727,.272727,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(256.4286,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.363636,.363636,1,1),fillOpacity=None,strokeColor=Color(.363636,.363636,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(259.2857,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.454545,.454545,1,1),fillOpacity=None,strokeColor=Color(.454545,.454545,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(262.1429,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.545455,.545455,1,1),fillOpacity=None,strokeColor=Color(.545455,.545455,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(265,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.636364,.636364,1,1),fillOpacity=None,strokeColor=Color(.636364,.636364,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(267.8571,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.727273,.727273,1,1),fillOpacity=None,strokeColor=Color(.727273,.727273,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(270.7143,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.818182,.818182,1,1),fillOpacity=None,strokeColor=Color(.818182,.818182,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(273.5714,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.909091,.909091,1,1),fillOpacity=None,strokeColor=Color(.909091,.909091,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(276.4286,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(1,1,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(279.2857,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.888889,.888889,1,1),fillOpacity=None,strokeColor=Color(.888889,.888889,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(282.1429,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.777778,.777778,1,1),fillOpacity=None,strokeColor=Color(.777778,.777778,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(285,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.666667,.666667,1,1),fillOpacity=None,strokeColor=Color(.666667,.666667,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(287.8571,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.555556,.555556,1,1),fillOpacity=None,strokeColor=Color(.555556,.555556,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(290.7143,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.444444,.444444,1,1),fillOpacity=None,strokeColor=Color(.444444,.444444,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(293.5714,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.333333,.333333,1,1),fillOpacity=None,strokeColor=Color(.333333,.333333,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(296.4286,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.222222,.222222,1,1),fillOpacity=None,strokeColor=Color(.222222,.222222,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(299.2857,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(.111111,.111111,1,1),fillOpacity=None,strokeColor=Color(.111111,.111111,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(302.1429,154.1667,2.857143,20.83333,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(245,154.1667,60,20.83333,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,350,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,50,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(200,50,200,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(350,50,350,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,125,45)
		v0.add(String(-20,-4,'Ying',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,275,45)
		v0.add(String(-21.66,-4,'Yang',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(50,50,50,175,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,45,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,84.72222,45,84.72222,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,119.4444,45,119.4444,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,154.1667,45,154.1667,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,50)
		v0.add(String(-5,-4,'0',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,84.72222)
		v0.add(String(-10,-4,'50',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,119.4444)
		v0.add(String(-15,-4,'100',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,154.1667)
		v0.add(String(-15,-4,'150',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
