#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Path
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_FillModeDrawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=600.0,height=200.0,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		v0=self._nn(Group())
		v0.transform = (1,0,0,-1,0,200)
		v0.add(Rect(1,1,599,199,rx=0,ry=0,fillColor=None,fillOpacity=1,strokeColor=Color(0,0,1,1),strokeWidth=2,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v1=v0._nn(Group())
		v1.transform = (.5,0,0,.5,0,0)
		v1.add(Path(points=[250,75,323,301,131,161,369,161,177,301],operators=[0,1,1,1,1,3],isClipPath=0,autoclose='svg',fillMode=0,fillColor=Color(1,0,0,1),fillOpacity=1,strokeColor=Color(0,0,0,1),strokeWidth=3,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (.309017,.951057,-0.951057,.309017,306.21,249)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (-0.809017,-0.587785,.587785,-0.809017,175.16,193.2)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (1,0,0,1,314.26,161)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (-0.809017,.587785,-0.587785,-0.809017,221.16,268.8)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (.309017,-0.951057,.951057,.309017,233.21,126.98)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v1.add(Path(points=[600,81,659.0945,81,707,128.9055,707,188,707,247.0945,659.0945,295,600,295,540.9055,295,493,247.0945,493,188,493,128.9055,540.9055,81,600,81,600,139,627.062,139,649,160.938,649,188,649,215.062,627.062,237,600,237,572.938,237,551,215.062,551,188,551,160.938,572.938,139,600,139],operators=[0,2,2,2,2,3,0,2,2,2,2,3],isClipPath=0,autoclose='svg',fillMode=0,fillColor=Color(1,0,0,1),fillOpacity=1,strokeColor=Color(0,0,0,1),strokeWidth=3,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (0,1,-1,0,707,188)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (-0.866025,-0.5,.5,-0.866025,546.5,280.6647)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (.866025,-0.5,.5,.866025,546.5,95.33528)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (-0.866025,.5,-0.5,-0.866025,624.5,230.4352)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (0,-1,1,0,551,188)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (.866025,.5,-0.5,.866025,624.5,145.5648)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v1.add(Path(points=[950,81,1009.094,81,1057,128.9055,1057,188,1057,247.0945,1009.094,295,950,295,890.9055,295,843,247.0945,843,188,843,128.9055,890.9055,81,950,81,950,139,922.938,139,901,160.938,901,188,901,215.062,922.938,237,950,237,977.062,237,999,215.062,999,188,999,160.938,977.062,139,950,139],operators=[0,2,2,2,2,3,0,2,2,2,2,3],isClipPath=0,autoclose='svg',fillMode=0,fillColor=Color(1,0,0,1),fillOpacity=1,strokeColor=Color(0,0,0,1),strokeWidth=3,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (0,1,-1,0,1057,188)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (-0.866025,-0.5,.5,-0.866025,896.5,280.6647)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (.866025,-0.5,.5,.866025,896.5,95.33528)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (.866025,-0.5,.5,.866025,974.5,230.4352)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (0,1,-1,0,901,188)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v2=v1._nn(Group())
		v2.transform = (-0.866025,-0.5,.5,-0.866025,974.5,145.5648)
		v2.add(Path(points=[16,0,-8,9,-8,-9],operators=[0,1,1,3],isClipPath=0,autoclose='svg',fillMode=1,fillColor=Color(0,0,0,1),fillOpacity=1,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_FillModeDrawing().save(formats=['pdf'],outDir='.',fnRoot=None)
