#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Line
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor
from rlextra.graphics.canvasadapter import DirectDrawFlowable

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Line(50,50,50,150,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,45,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,75,45,75,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,100,45,100,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,125,45,125,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,150,45,150,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,50)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-14,-6)
		v1.add(DirectDrawFlowable(XPreformatted(
'caseSensitive': 1
'text': '10<sup>2</sup>'
'frags': [ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='2', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 14.0
'height': 12.0
'blPara': ParaLines(kind=1, lines=[ParaLines(ascent=6.83, currentWidth=14.0, descent=-2.17, extraSpace=2147483633.0, fontSize=10, preformatted=True, wordCount=0, words=[ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='2', textColor=Color(0,0,0,1), us_lines=[])])])
) #XPreformatted))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,75)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-14,-6)
		v1.add(DirectDrawFlowable(XPreformatted(
'caseSensitive': 1
'text': '10<sup>3</sup>'
'frags': [ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='3', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 14.0
'height': 12.0
'blPara': ParaLines(kind=1, lines=[ParaLines(ascent=6.83, currentWidth=14.0, descent=-2.17, extraSpace=2147483633.0, fontSize=10, preformatted=True, wordCount=0, words=[ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='3', textColor=Color(0,0,0,1), us_lines=[])])])
) #XPreformatted))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,100)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-14,-6)
		v1.add(DirectDrawFlowable(XPreformatted(
'caseSensitive': 1
'text': '10<sup>4</sup>'
'frags': [ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='4', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 14.0
'height': 12.0
'blPara': ParaLines(kind=1, lines=[ParaLines(ascent=6.83, currentWidth=14.0, descent=-2.17, extraSpace=2147483633.0, fontSize=10, preformatted=True, wordCount=0, words=[ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='4', textColor=Color(0,0,0,1), us_lines=[])])])
) #XPreformatted))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,125)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-14,-6)
		v1.add(DirectDrawFlowable(XPreformatted(
'caseSensitive': 1
'text': '10<sup>5</sup>'
'frags': [ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='5', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 14.0
'height': 12.0
'blPara': ParaLines(kind=1, lines=[ParaLines(ascent=6.83, currentWidth=14.0, descent=-2.17, extraSpace=2147483633.0, fontSize=10, preformatted=True, wordCount=0, words=[ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='5', textColor=Color(0,0,0,1), us_lines=[])])])
) #XPreformatted))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,150)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-14,-6)
		v1.add(DirectDrawFlowable(XPreformatted(
'caseSensitive': 1
'text': '10<sup>6</sup>'
'frags': [ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='6', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 14.0
'height': 12.0
'blPara': ParaLines(kind=1, lines=[ParaLines(ascent=6.83, currentWidth=14.0, descent=-2.17, extraSpace=2147483633.0, fontSize=10, preformatted=True, wordCount=0, words=[ParaFrag(__tag__='para', bold=0, fontName='Times-Roman', fontSize=10, greek=0, italic=0, link=[], rise=0, text='10', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', bold=0, fontName='Times-Roman', fontSize=8, greek=0, italic=0, link=[], rise=5.0, text='6', textColor=Color(0,0,0,1), us_lines=[])])])
) #XPreformatted))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
