#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Wedge
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=400,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Wedge(200,200,150,0,120,yradius=None,annular=False,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=100))
		self.add(Wedge(200,200,150,120,240,yradius=None,annular=False,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=100))
		self.add(Wedge(200,200,150,240,260,yradius=None,annular=False,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=100))
		self.add(Wedge(200,200,150,260,360,yradius=None,annular=False,fillColor=Color(.501961,.501961,.501961,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=100))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
